import { ERC20Token, ChainId } from '@pancakeswap/sdk'
import getLpAddress from 'utils/getLpAddress'

const CAKE_AS_STRING = '0x7DbF199731A3CCC3445b99c130171646314fcB44'
const BUSD_AS_STRING = '0xA0b86991c6218b36c1d19D4a2e9Eb0cE3606eB48'
const CAKE_AS_TOKEN = new ERC20Token(ChainId.ETHEREUM, CAKE_AS_STRING, 18)
const BUSD_AS_TOKEN = new ERC20Token(ChainId.ETHEREUM, BUSD_AS_STRING, 18)
const CAKE_BUSD_LP = '0x706236cf5E318EFf9939d7721B8c42Eb0aCA6c18'

describe('getLpAddress', () => {
  it('returns correct LP address, both tokens are strings', () => {
    expect(getLpAddress(CAKE_AS_STRING, BUSD_AS_STRING)).toBe(CAKE_BUSD_LP)
  })
  it('returns correct LP address, token1 is string, token 2 is Token', () => {
    expect(getLpAddress(CAKE_AS_STRING, BUSD_AS_TOKEN)).toBe(CAKE_BUSD_LP)
  })
  it('returns correct LP address, both tokens are Token', () => {
    expect(getLpAddress(CAKE_AS_TOKEN, BUSD_AS_TOKEN)).toBe(CAKE_BUSD_LP)
  })
  it('returns null if any address is invalid', () => {
    expect(getLpAddress('123', '456')).toBe(null)
    expect(getLpAddress(undefined, undefined)).toBe(null)
    expect(getLpAddress(CAKE_AS_STRING, undefined)).toBe(null)
    expect(getLpAddress(undefined, BUSD_AS_TOKEN)).toBe(null)
    expect(getLpAddress(CAKE_AS_STRING, '456')).toBe(null)
    expect(getLpAddress('123', BUSD_AS_TOKEN)).toBe(null)
  })
})
